from django.conf import settings
from pytest_django.asserts import assertInHTML, assertJSONEqual

from tests.testapp.models import SimplePage


validity = {
    'is_valid': True
}

if settings.WAGTAIL_VERSION >= (4, 0):
    validity['is_available'] = True


def test_preview(admin_client):
    simple_page = SimplePage.objects.first()

    post_data = {
        'title': "Accessibility",
        'slug': 'accessibility',
    }

    preview_url = "/admin/pages/{}/edit/preview/".format(simple_page.pk)
    response = admin_client.post(preview_url, post_data)

    # Check the JSON response
    assert response.status_code == 200
    assertJSONEqual(response.content.decode(), validity)

    # Check the user can refresh the preview
    preview_session_key = 'wagtail-preview-{}'.format(simple_page.pk)
    assert preview_session_key in admin_client.session

    response = admin_client.get(preview_url)

    # Check the HTML response
    assert response.status_code == 200
    assertInHTML(
        '<script src="/static/js/tota11y.min.js"></script>',
        response.content.decode(),
    )



import os

import django
from django.test.utils import override_settings
import pytest


def pytest_configure():
    os.environ.setdefault("DJANGO_SETTINGS_MODULE", "tests.settings")
    django.setup()


@pytest.fixture(scope="session", autouse=True)
def custom_settings(tmpdir_factory):
    overrides = override_settings(MEDIA_ROOT=str(tmpdir_factory.mktemp("media")))
    overrides.enable()


import os

from wagtail import VERSION as WAGTAIL_VERSION

BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

ALLOWED_HOSTS = ["*"]

SECRET_KEY = "ThisIsForTestingOnly"

INSTALLED_APPS = [
    "wagtailaccessibility",
    "tests.testapp",

    'wagtail.contrib.forms',
    'wagtail.contrib.redirects',
    'wagtail.embeds',
    'wagtail.sites',
    'wagtail.users',
    'wagtail.snippets',
    'wagtail.documents',
    'wagtail.images',
    'wagtail.search',
    'wagtail.admin',
    "wagtail",

    "taggit",
    "modelcluster",

    "django.contrib.admin",
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.sessions",
    "django.contrib.messages",
    "django.contrib.sites",
    "django.contrib.staticfiles",
]

DATABASES = {
    "default": {
        "ENGINE": "django.db.backends.sqlite3",
        "NAME": ":memory:",
    }
}

MIDDLEWARE = [
    "django.middleware.security.SecurityMiddleware",
    "django.contrib.sessions.middleware.SessionMiddleware",
    "django.middleware.common.CommonMiddleware",
    "django.middleware.csrf.CsrfViewMiddleware",
    "django.contrib.auth.middleware.AuthenticationMiddleware",
    "django.contrib.messages.middleware.MessageMiddleware",
    "django.middleware.clickjacking.XFrameOptionsMiddleware",
    "wagtail.contrib.redirects.middleware.RedirectMiddleware",
]

TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "DIRS": [],
        "APP_DIRS": True,
        "OPTIONS": {
            "context_processors": [
                "django.template.context_processors.debug",
                "django.template.context_processors.request",
                "django.contrib.auth.context_processors.auth",
                "django.contrib.messages.context_processors.messages",
            ]
        },
    }
]

ROOT_URLCONF = "tests.urls"

DEFAULT_AUTO_FIELD = "django.db.models.AutoField"

CACHES = {
    "default": {
        "BACKEND": "django.core.cache.backends.locmem.LocMemCache",
        "LOCATION": "unique-snowflake",
    }
}

STATICFILES_FINDERS = [
    'django.contrib.staticfiles.finders.FileSystemFinder',
    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
]

STATICFILES_DIRS = [
    os.path.join(BASE_DIR, 'staticfiles'),
]

STATIC_ROOT = os.path.join(BASE_DIR, 'static')
STATIC_URL = '/static/'

WAGTAILADMIN_BASE_URL = "http://example.com"

USE_TZ = False



#!/usr/bin/env python

from setuptools import find_packages, setup  # type: ignore

with open("README.md", encoding="utf-8") as readme_file:
    long_description = readme_file.read()


install_requires = [
    'wagtail>=4.1',
]

tests_require = [
    "pytest==6.2.5",
    "pytest-cov==3.0.0",
    "pytest-django==4.5.0",
    "pytest-pythonpath==0.7.3",
    "coverage==6.0",
]

setup(
    name='wagtail-accessibility',
    version='2.0.0',
    description="Accessibility content checks for Wagtail websites",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='Wagtail Nest contributors',
    author_email='hello@wagtail.org',
    url='https://github.com/wagtail-nest/wagtail-accessibility',

    install_requires=install_requires,
    tests_require=tests_require,
    extras_require={
        "test": tests_require,
    },
    zip_safe=False,
    license='BSD License',

    packages=find_packages(),

    include_package_data=True,
    package_data={},

    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Development Status :: 5 - Production/Stable',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Internet :: WWW/HTTP :: Site Management',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        "Framework :: Django",
        "Framework :: Django :: 4.2",
        "Framework :: Django :: 5.0",
        "Framework :: Wagtail",
        "Framework :: Wagtail :: 4",
        "Framework :: Wagtail :: 5",
        'License :: OSI Approved :: BSD License',
    ],
)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations


def create_simplepage(apps, schema_editor):
    # Get models
    ContentType = apps.get_model('contenttypes.ContentType')
    Page = apps.get_model('wagtailcore.Page')
    Site = apps.get_model('wagtailcore.Site')
    SimplePage = apps.get_model('testapp.SimplePage')

    # Delete the default simplepage
    # If migration is run multiple times, it may have already been deleted
    Page.objects.filter(id=2).delete()

    # Create content type for simplepage model
    simplepage_content_type, __ = ContentType.objects.get_or_create(
        model='simplepage', app_label='testapp')

    # Create a new simplepage
    simplepage = SimplePage.objects.create(
        title="Home",
        draft_title="Home",
        slug='testapp',
        content_type=simplepage_content_type,
        path='00010001',
        depth=2,
        numchild=0,
        url_path='/testapp/',
    )

    # Create a site with the new simplepage set as the root
    Site.objects.create(
        hostname='localhost', root_page=simplepage, is_default_site=True)


def remove_simplepage(apps, schema_editor):
    # Get models
    ContentType = apps.get_model('contenttypes.ContentType')
    SimplePage = apps.get_model('testapp.SimplePage')

    # Delete the default simplepage
    # Page and Site objects CASCADE
    SimplePage.objects.filter(slug='testapp', depth=2).delete()

    # Delete content type for simplepage model
    ContentType.objects.filter(model='simplepage', app_label='testapp').delete()


class Migration(migrations.Migration):

    dependencies = [
        ('testapp', '0001_initial'),
    ]

    operations = [
        migrations.RunPython(create_simplepage, remove_simplepage),
    ]
